@@ -129,33 +129,67 @@ class ZbxCommon(object):
         self.obj_token = ''
         self.auth_uuid = ''
         self.token = ''
+        self.modules = {'zmq': 'pyzmq==19.0.2', 'pymysql': 'PyMySQL==0.9.2', 'kafka': 'kafka==1.3.5',
+                        'redis': 'redis==3.5.3', 'yaml': 'PyYAML==5.3.1', 'pyquery': 'pyquery==1.4.3',
+                        'elasticsearch': 'elasticsearch==7.17.4', 'flask': 'Flask==1.0.2',
+                        'requests': 'requests==2.25.0'}
+        if PY3:
+            self.modules['kafka'] = 'kafka-python==2.0.2'
+            self.modules['zmq'] = 'pyzmq==23.2.0'
+            self.modules['flask'] = 'Flask==2.0.1'
+            self.modules['elasticsearch'] = 'elasticsearch==8.3.1'
         if len(sys.argv) == 2 and len(sys.argv[1]) == 36:
             self.get_param('')
 
+    def gen_requirements(self, path=''):
+        mods = []
+        for k, v in self.modules.items():
+            mods.append(v)
+        if path != '':
+            with open(path + '/requirement.txt', 'w+') as fp:
+                fp.write("\n".join(mods))
+        else:
+            print("\n".join(mods))
+
     def init_log(self):
-        global logger, log, IS_INIT_GLOBAL_LOG
-        if not IS_INIT_GLOBAL_LOG:
-            IS_INIT_GLOBAL_LOG = True
-            self.log = init_log()
-            logger = self.log
+        pass
+        # global logger, log, IS_INIT_GLOBAL_LOG
+        # if not IS_INIT_GLOBAL_LOG:
+        #     IS_INIT_GLOBAL_LOG = True
+        #     self.log = init_log()
+        #     logger = self.log
 
     @classmethod
-    def try_except_log(cls):
-        def decorator(func):
+    def retry(cls, tries=3, interval=1):
+        return ZbxCommon.try_except(tries, interval)
+
+    @classmethod
+    def try_except(cls, tries=0, interval=1):
+        def decorate(func):
             import functools
+
             @functools.wraps(func)
             def wrapper(*args, **kwargs):
-                try:
-                    return func(*args, **kwargs)
-                except Exception as err:
-                    name = ''
-                    if hasattr(func, '__name__'):
-                        name = getattr(func, '__name__')
-                    logger.error('func name:' + name + "\t" + str(err))
+                count = 0
+                while True:
+                    try:
+                        result = func(*args, **kwargs)
+                    except Exception as e:
+                        import traceback
+                        logger.error(traceback.format_exc())
+                        count += 1
+                        if count > tries:
+                            if tries != 0:
+                                logger.error('retry max times')
+                            break
+                        else:
+                            time.sleep(interval)
+                    else:
+                        return result
 
             return wrapper
 
-        return decorator
+        return decorate
 
     def urlencode(self, str):
         reprStr = repr(str).replace(r'\x', '%')
@@ -1002,7 +1036,8 @@ class ZbxCommon(object):
             table_data = self.mysql_query(conn, sql)
             fpath = '{dir}/{table}.sql'.format(dir=dir, table=table)
             sql_str = self.dict2sql(table, table_data)
-            data_map[table] = sql_str
+            if dir == '':
+                data_map[table] = sql_str
             if dir != '':
                 if not os.path.exists(fpath):
                     with open(fpath, 'w+') as fp:
@@ -1033,11 +1068,57 @@ class ZbxCommon(object):
         import pymysql
         return pymysql
 
+    @property
+    def flask(self):
+        import flask
+        return flask
+
     @property
     def pyquery(self):
         import pyquery
         return pyquery
 
+    @property
+    def yaml(self):
+        import yaml
+        return yaml
+
+    @property
+    def elasticsearch(self):
+        import elasticsearch
+        return elasticsearch
+
+    def yaml2json(self, yaml):
+        if os.path.isfile(yaml):
+            with open(yaml, 'r') as fp:
+                data = self.yaml.safe_load(fp)
+                return json.dumps(data, indent=2)
+        return json.dumps(self.yaml.load(yaml, Loader=self.yaml.FullLoader), indent=2)
+
+    def json2yaml(self, jsonobj):
+        if os.path.isfile(jsonobj):
+            with open(jsonobj, 'r') as fp:
+                data = json.load(fp)
+                return self.yaml.dump(data)
+        return self.yaml.safe_dump(json.loads(jsonobj))
+
+    def get_flask_app(self):
+        app = self.flask.Flask(__name__)
+        from flask import request
+        from flask import session
+        app.request = request
+        app.session = session
+        return app
+
+    def get_flask_response(self):
+        from flask import make_response
+        return make_response()
+
+    @property
+    def zmq(self):
+        import zmq
+        return zmq
+
     @property
     def redis(self):
         import redis
@@ -1610,7 +1691,46 @@ except Exception as er:
 cli = ZbxCommon()
 
 
-@cli.try_except_log()
+@cli.try_except()
+def handle_exception(exc_type, exc_value, exc_traceback):
+    if issubclass(exc_type, KeyboardInterrupt):
+        sys.__excepthook__(exc_type, exc_value, exc_traceback)
+        return
+    logger.error("Uncaught exception", exc_info=(exc_type, exc_value, exc_traceback))
+
+
+sys.excepthook = handle_exception
+
+
+def try_except(tries=0, interval=1):
+    def decorate(func):
+        import functools
+
+        @functools.wraps(func)
+        def wrapper(*args, **kwargs):
+            count = 0
+            while True:
+                try:
+                    result = func(*args, **kwargs)
+                except Exception as e:
+                    import traceback
+                    logger.error(traceback.format_exc())
+                    count += 1
+                    if count > tries:
+                        if tries != 0:
+                            logger.error('retry max times')
+                        break
+                    else:
+                        time.sleep(interval)
+                else:
+                    return result
+
+        return wrapper
+
+    return decorate
+
+
+@cli.try_except()
 def __check_module():
     mds = cli.get_dependencies()
     if len(mds) > 0:
@@ -1784,6 +1904,19 @@ cli.dump_mysql_ddl(conn,"/tmp/ferry")
 
 print(cli.get_dependencies())
 
+yaml=\'\'\'
+Section:
+    heading: Heading 1
+    font: 
+        name: Times New Roman
+        size: 22
+        color_theme: ACCENT_2
+\'\'\'
+
+a=cli.yaml2json(yaml)
+b=cli.json2yaml(a)
+
+
 tpl=\'\'\'
 <dl>
     {% for key, value in d.items() %}
