@@ -139,16 +139,64 @@ from base import *
 #     time.sleep(1)
 
 
+# yaml='''
+# Section:
+#     heading: Heading 1
+#     font:
+#         name: Times New Roman
+#         size: 22
+#         color_theme: ACCENT_2
+# '''
+#
+# a=cli.yaml2json(yaml)
+# b=cli.json2yaml(a)
+# print(a)
+# print(b)
 
-# cli.init_log()
-
-cli.log.info("sdfasdfasd")
+# def server():
+#
+#     import zmq
+#
+#     context = zmq.Context()
+#     socket = context.socket(zmq.REP)
+#     socket.bind("tcp://*:5555")
+#
+#     while True:
+#         message = socket.recv()
+#         print("Received: %s" % message)
+#         socket.send("I am OK!".encode('utf-8'))
+#
+# import threading
+# svc=threading.Thread(target=server)
+# svc.setDaemon(True)
+# svc.start()
+#
+# from concurrent.futures import ThreadPoolExecutor
+#
+# import zmq
+# context = zmq.Context()
+# socket = context.socket(zmq.REQ)
+# socket.connect("tcp://localhost:5555")
+#
+# time.sleep(3)
+#
+# socket.send('Are you OK?'.encode('utf-8'))
+# response = socket.recv()
+# print("response: %s" % response)
 
 
+cli.gen_requirements(".")
 
-@cli.try_except_log()
-def aa():
-    a=0
-    print(1/a)
+# app=cli.get_flask_app()
+# from flask import request
+# app.config['SECRET_KEY']=os.urandom(24)
+# @app.route("/")
+# def hello():
+#
+#     respose= cli.get_flask_response()
+#     respose.data='xxx'
+#     respose.status=404
+#     return respose
+#
+# app.run('0.0.0.0',port=8000,debug=True)
 
-aa()
\ No newline at end of file
